package com.tuoheng.admin.controller;

import com.tuoheng.admin.dto.TenantDto;
import com.tuoheng.admin.entity.Tenant;
import com.tuoheng.admin.query.TenantQuery;
import com.tuoheng.admin.service.ITenantService;
import com.tuoheng.common.annotation.Log;
import com.tuoheng.common.common.BaseController;
import com.tuoheng.common.enums.LogType;
import com.tuoheng.common.utils.JsonResult;
import com.tuoheng.system.entity.Level;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * <p>
 * 企业管理表 前端控制器
 * </p>
 *
 * @author 拓恒
 * @since 2022-07-15
 */
@RestController
@RequestMapping("/tenant")
public class TenantController extends BaseController {
    @Autowired
    private ITenantService tenantService;

    /**
     * 获取租户列表
     *
     * @param levelQuery 查询条件
     * @return
     */
    @GetMapping("/index")
    public JsonResult index(TenantQuery levelQuery) {
        return tenantService.getTenantList(levelQuery);
    }

    /**
     * 添加租户
     *
     * @param tenantDto 实体对象
     * @return
     */
    @PostMapping("/add")
    public JsonResult add(@RequestBody TenantDto tenantDto) {
        return tenantService.addTenant(tenantDto);
    }

    /**
     * 编辑租户
     *
     * @param tenantDto 实体对象
     * @return
     */
    @PutMapping("/edit")
    public JsonResult edit(@RequestBody TenantDto tenantDto) {

        return tenantService.editTenant(tenantDto);
    }

    /**
     * 删除租户
     *
     * @param tenantIds 职级ID
     * @return
     */
    @DeleteMapping("/delete/{tenantIds}")
    public JsonResult delete(@PathVariable("tenantIds") Integer[] tenantIds) {
        return tenantService.deleteByIds(tenantIds);
    }

    /**
     * 设置状态
     *
     * @param entity 实体对象
     * @return
     */
    @PutMapping("/status")
    public JsonResult status(@RequestBody Tenant entity) {
        return tenantService.setStatus(entity);
    }
}
